@@ -85,7 +85,7 @@ print.bigq <- function(x, quote = FALSE, initLine = TRUE, ...)
   invisible(x)
 }
 
-as.bigq <- function(n, d=1)
+as.bigq <- function(n, d = 1L)
 {
     .Call(bigrational_as, n, d)
 }
@@ -102,9 +102,9 @@ formatN.bigq	<- function(x, ...) {
     r
 }
 
-as.double.bigq<- function(x,...) .Call(bigrational_as_numeric, x)
+as.double.bigq <- function(x,...) .Call(bigrational_as_numeric, x)
 ## maybe sub-optimal, but at least "R-consistent" in warnings/errors...:
-as.integer.bigq<- function(x,...) as.integer(.Call(bigrational_as_numeric, x))
+as.integer.bigq <- function(x,...) as.integer(.Call(bigrational_as_numeric, x))
 
 .bigq2num <- function(x) {
     ## cat(".bigq2num():\n")
@@ -138,7 +138,7 @@ as.bigz.bigq <- function(a, mod = NA)
 {
   ## "FIXME":  considerably faster in C / C++
   if(any(ina <- is.na.bigq(a))) {
-    r <- as.bigz(rep.int(NA, length(a)))
+    r <- rep.bigz(NA_bigz_, length(a))
     if(any(ii <- !ina)) {
 	a <- a[ii]
 	r[ii] <- as.bigz(numerator(a) %/% denominator(a), mod[ii])
@@ -205,19 +205,29 @@ trunc.bigq <- function(x, ...) ## := sign(x) * floor(abs(x)) =
     sign.bigq(x) * as.bigz.bigq(abs.bigq(x))
 floor.bigq   <- function(x) as.bigz.bigq(x)
 ceiling.bigq <- function(x) -as.bigz.bigq(-x)
-round.bigq <- function(x, digits = 0) {
-    ## round(x * 10^d) / 10^d
-    bigq_half <- as.bigq(1, 2)
-    round0 <- function(x) as.bigz.bigq(x + bigq_half)
-    stopifnot(length(digits) == 1L)
-    if(digits == 0)
-        round0(x)
-    else {
-        p10 <- as.bigz(10) ^ digits # bigz iff digits >= 0,  bigq otherwise
-        round0(x * p10) / p10
+
+if(FALSE) ## this was used in round.bigq() for several months in 2020:
+round0 <- function(x) as.bigz.bigq(x + as.bigq(1, 2))
+
+##' rounding to integer a la "nearbyint()" -- i.e. "round to even"
+round0 <- function(x) {
+    nU <- as.bigz.bigq(xU <- x + as.bigq(1, 2)) # traditional round: .5 rounded up
+    if(any(I <- is.whole.bigq(xU))) { # I <==>  x == <n>.5 : "hard case"
+        I[I] <- .mod.bigz(nU[I], 2L) == 1L # rounded up is odd  ==> round *down*
+        nU[I] <- nU[I] - 1L
     }
+    nU
 }
 
+roundQ <- function(x, digits = 0, r0 = round0) {
+    ## round(x * 10^d) / 10^d --  vectorizing in both (x, digits)
+    p10 <- as.bigz(10) ^ digits # class: if(all(digits >= 0)) "bigz" else "bigq"
+    r0(x * p10) / p10
+}
+
+##' round() method ==> signature = (x, digits)  {round0 *not* allowed as argument}
+round.bigq <- function(x, digits = 0) roundQ(x, digits)
+
 cumsum.bigq <- function(x) .Call(bigrational_cumsum, x)
 ## TODO: add cummax(), cummin(), cumprod()
 
@@ -227,10 +237,10 @@ cumsum.bigq <- function(x) .Call(bigrational_cumsum, x)
 
 
 
+##' to be applied e.g. to the result of  lapply(<bigq>, Fn)
+c_bigq <- function(L) .Call(bigrational_c, L)
 
-c.bigq <- function(..., recursive = FALSE) {
-    .Call(bigrational_c, list(...))
-}
+c.bigq <- function(..., recursive = FALSE) c_bigq(list(...))
 
 ## This is practically identical to  grid :: rep.unit :
 rep.bigq <- function(x, times=1, length.out=NA, each=1, ...) {
