@@ -17,14 +17,14 @@ SEXP gmpMatToListZ(SEXP X, SEXP line)
 
   SEXP ans;
   // dangerous... no check => use with care in R
-  bool lines =  INTEGER(line)[0];
+  int lines =  INTEGER(line)[0];
 
   bigvec matrix = bigintegerR::create_bignum(X);
 
   unsigned int ncol = matrix.size() / matrix.nrow;
   unsigned int nrow =  matrix.nrow;
 
-  if(lines)
+  if(lines == 1)
     {
       // RETURN a list of all lines
       PROTECT (ans = NEW_LIST(matrix.nrow) );
